==> vcremote-1.0.10.tgz: package/lib/darwin/darwin-specifics.js <==
﻿/**
* ******************************************************
*                                                       *
*   Copyright (C) Microsoft. All rights reserved.       *
*                                                       *
*******************************************************
*/
/// <reference path="../../../typings/nconf.d.ts" />
/// <reference path="../../../typings/Q.d.ts" />
/// <reference path="../../../typings/vcremote-utils.d.ts" />
/// <reference path="../../../typings/express.d.ts" />
/// <reference path="../../../typings/zip-stream.d.ts" />
"use strict";
var child_process = require("child_process");

var fs = require("fs");
var nconf = require("nconf");
var path = require("path");
var Q = require("q");
var readline = require("readline");

var certs = require("./darwin-certs");

var utils = require("vcremote-utils");

var resources = utils.ResourcesManager;

var allowsEmulate;
var nativeDebugProxyPort;
var webDebugProxyDevicePort;
var webDebugProxyPortMin;
var webDebugProxyPortMax;

var DarwinSpecifics = (function () {
    function DarwinSpecifics() {
    }
    DarwinSpecifics.prototype.defaults = function (base) {
        var osxdefaults = {
            serverDir: path.join(process.env.HOME, require("../../package").name),
            nativeDebugProxyPort: 3031,
            debugListenerPort: 3032,
            webDebugProxyDevicePort: 9221,
            webDebugProxyRangeMin: 9222,
            webDebugProxyRangeMax: 9322,
            writePidToFile: false,
            lang: process.env.LANG && process.env.LANG.replace(/_.*/, "") || "en",
            suppressVisualStudioMessage: false
        };
        Object.keys(osxdefaults).forEach(function (key) {
            if (!(key in base)) {
                base[key] = osxdefaults[key];
            }
        });

        return base;
    };

    // Note: we acquire dependencies for deploying and debugging here rather than in vcremote-lib because it may require user intervention, and vcremote-lib may be acquired unattended in future.
    DarwinSpecifics.prototype.initialize = function () {
        if (process.getuid() === 0) {
            console.warn(resources.getStringForLanguage(nconf.get("lang"), "NotRunAsRoot"));
            process.exit(1);
        }

        var firstRunPath = path.join(process.env.HOME, ".vcremote");
        var isFirstRun = !fs.existsSync(firstRunPath);
        var deferred = Q.defer();
        if (isFirstRun) {
            console.info(resources.getStringForLanguage(nconf.get("lang"), "FirstRunDependencyConfiguration"));
            var readlineInterface = readline.createInterface({ input: process.stdin, output: process.stdout });
            var deferred2 = Q.defer();
            readlineInterface.question(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationQuery"), function (response) {
                var shouldInstall = response === "" || response.trim().toLowerCase().indexOf(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationQueryResponse")) === 0;

                if (shouldInstall) {
                    var homebrewInstalled = Q.defer();

                    // We use spawn here rather than exec primarily so we can allow for user-interaction
                    var curlInstaller = child_process.spawn("curl", ["-fsSL", "https://raw.githubusercontent.com/Homebrew/install/master/install"]);
                    var installHomebrew = child_process.spawn("ruby", ["-"]);

                    curlInstaller.stdout.on("data", function (data) {
                        installHomebrew.stdin.write(data);
                    });
                    curlInstaller.on("close", function (code) {
                        installHomebrew.stdin.end();
                    });

                    installHomebrew.stdout.on("data", function (data) {
                        console.info("" + data);
                    });
                    installHomebrew.stderr.on("data", function (data) {
                        console.error("" + data);
                    });
                    installHomebrew.on("close", function (code) {
                        homebrewInstalled.resolve({});
                    });
                    installHomebrew.on("error", function (arg) {
                        console.error("ERROR: " + JSON.stringify(arg));
                        process.exit(1);
                    });

                    homebrewInstalled.promise.then(function () {
                        // Install these packages if they do not exist.
                        // We need to check first since the install will fail if an older version is already installed.
                        // ideviceinstaller and ios-webkit-debug-proxy will install libimobiledevice if required
                        return Q.denodeify(child_process.exec)("(brew list ideviceinstaller | grep ideviceinstaller > /dev/null || brew install ideviceinstaller) && \
                                                            (brew list ios-webkit-debug-proxy | grep ios-webkit-debug-proxy > /dev/null || brew install ios-webkit-debug-proxy)");
                    }).then(function () {
                        // Verify that both of these can run.
                        Q.denodeify(child_process.exec)("ideviceinstaller -h > /dev/null && ios_webkit_debug_proxy -h > /dev/null").then(function () {
                            console.info(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationSuccess"));
                            deferred2.resolve(shouldInstall);
                        }, function (error) {
                            console.error(resources.getStringForLanguage(nconf.get("lang"), "HomebrewPackageVerificationFailed", error));
                            process.exit(1);
                        });
                    }, function (error) {
                        console.error(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationFailed", error));
                        process.exit(1);
                    });
                } else {
                    console.info(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationDeclined"));
                    deferred2.resolve(shouldInstall);
                }
            });

            deferred2.promise.then(function (shouldInstall) {
                child_process.exec("(DevToolsSecurity -enable || true)", function () {
                    // Write to the file. We don't read the contents, but it may help with user discoverability if they change their mind
                    fs.writeFileSync(firstRunPath, "installHomebrew = " + (shouldInstall ? "yes" : "no") + "\n");
                    deferred.resolve({});
                });
            });
        } else {
            deferred.resolve({});
        }

        return deferred.promise;
    };

    DarwinSpecifics.prototype.printUsage = function (language) {
        console.info(resources.getStringForLanguage(language, "UsageInformation"));
    };

    DarwinSpecifics.prototype.resetServerCert = function (conf) {
        return certs.resetServerCert(conf);
    };

    DarwinSpecifics.prototype.generateClientCert = function (conf) {
        return certs.generateClientCert(conf);
    };

    DarwinSpecifics.prototype.initializeServerCerts = function (conf) {
        return certs.initializeServerCerts(conf);
    };

    DarwinSpecifics.prototype.getServerCerts = function (conf) {
        return certs.getServerCerts(conf);
    };

    DarwinSpecifics.prototype.removeAllCertsSync = function (conf) {
        certs.removeAllCertsSync(conf);
    };

    DarwinSpecifics.prototype.downloadClientCerts = function (req, res) {
        Q.fcall(certs.downloadClientCerts, req.params.pin).catch(function (error) {
            if (error.code) {
                res.send(error.code, resources.getStringForLanguage(req, error.id));
            } else {
                res.send(404, error);
            }

            return "";
        }).then(function (pfxFile) {
            res.sendfile(pfxFile);
        }).then(function () {
            certs.invalidatePIN(req.params.pin);
        }).done();
    };
    return DarwinSpecifics;
})();

var darwinSpecifics = new DarwinSpecifics();
module.exports = darwinSpecifics;

==> vcremote-1.0.16.tgz: package/lib/darwin/darwin-specifics.js <==
/**
  * ******************************************************
  *                                                       *
  *   Copyright (C) Microsoft. All rights reserved.       *
  *                                                       *
  *******************************************************
  */
"use strict";
const child_process = require("child_process");
const fs = require("fs");
const nconf = require("nconf");
const path = require("path");
const Q = require("q");
const readline = require("readline");
const certs = require("./darwin-certs");
const utils = require("vcremote-utils");
var resources = utils.ResourcesManager;
var allowsEmulate;
var nativeDebugProxyPort;
var webDebugProxyDevicePort;
var webDebugProxyPortMin;
var webDebugProxyPortMax;
class DarwinSpecifics {
    defaults(base) {
        var osxdefaults = {
            serverDir: path.join(process.env.HOME, require("../../package").name),
            nativeDebugProxyPort: 3031,
            debugListenerPort: 3032,
            webDebugProxyDevicePort: 9221,
            webDebugProxyRangeMin: 9222,
            webDebugProxyRangeMax: 9322,
            writePidToFile: false,
            lang: process.env.LANG && process.env.LANG.replace(/_.*/, "") || "en",
            suppressVisualStudioMessage: false,
        };
        Object.keys(osxdefaults).forEach(function (key) {
            if (!(key in base)) {
                base[key] = osxdefaults[key];
            }
        });
        return base;
    }
    // Note: we acquire dependencies for deploying and debugging here rather than in vcremote-lib because it may require user intervention, and vcremote-lib may be acquired unattended in future.
    initialize() {
        if (process.getuid() === 0) {
            console.warn(resources.getStringForLanguage(nconf.get("lang"), "NotRunAsRoot"));
            process.exit(1);
        }
        var firstRunPath = path.join(process.env.HOME, ".vcremote");
        var isFirstRun = !fs.existsSync(firstRunPath);
        var deferred = Q.defer();
        if (isFirstRun) {
            console.info(resources.getStringForLanguage(nconf.get("lang"), "FirstRunDependencyConfiguration"));
            var readlineInterface = readline.createInterface({ input: process.stdin, output: process.stdout });
            var deferred2 = Q.defer();
            readlineInterface.question(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationQuery"), function (response) {
                var shouldInstall = response === "" || response.trim().toLowerCase().indexOf(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationQueryResponse")) === 0;
                if (shouldInstall) {
                    var homebrewInstalled = Q.defer();
                    // We use spawn here rather than exec primarily so we can allow for user-interaction
                    var curlInstaller = child_process.spawn("curl", ["-fsSL", "https://raw.githubusercontent.com/Homebrew/install/master/install"]);
                    var installHomebrew = child_process.spawn("ruby", ["-"]);
                    curlInstaller.stdout.on("data", function (data) {
                        installHomebrew.stdin.write(data);
                    });
                    curlInstaller.on("close", function (code) {
                        installHomebrew.stdin.end();
                    });
                    installHomebrew.stdout.on("data", function (data) {
                        console.info("" + data);
                    });
                    installHomebrew.stderr.on("data", function (data) {
                        console.error("" + data);
                    });
                    installHomebrew.on("close", function (code) {
                        homebrewInstalled.resolve({});
                    });
                    installHomebrew.on("error", function (arg) {
                        console.error("ERROR: " + JSON.stringify(arg));
                        process.exit(1);
                    });
                    homebrewInstalled.promise.then(function () {
                        // Install these packages if they do not exist.
                        // We need to check first since the install will fail if an older version is already installed.
                        // ideviceinstaller and ios-webkit-debug-proxy will install libimobiledevice if required
                        return Q.denodeify(child_process.exec)("(brew list ideviceinstaller | grep ideviceinstaller > /dev/null || brew install ideviceinstaller) && \
                                                            (brew list ios-webkit-debug-proxy | grep ios-webkit-debug-proxy > /dev/null || brew install ios-webkit-debug-proxy)");
                    }).then(function () {
                        // Verify that both of these can run.
                        Q.denodeify(child_process.exec)("ideviceinstaller -h > /dev/null && ios_webkit_debug_proxy -h > /dev/null")
                            .then(function () {
                            console.info(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationSuccess"));
                            deferred2.resolve(shouldInstall);
                        }, function (error) {
                            console.error(resources.getStringForLanguage(nconf.get("lang"), "HomebrewPackageVerificationFailed", error));
                            process.exit(1);
                        });
                    }, function (error) {
                        console.error(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationFailed", error));
                        process.exit(1);
                    });
                }
                else {
                    console.info(resources.getStringForLanguage(nconf.get("lang"), "HomebrewInstallationDeclined"));
                    deferred2.resolve(shouldInstall);
                }
            });
            deferred2.promise.then(function (shouldInstall) {
                child_process.exec("(DevToolsSecurity -enable || true)", function () {
                    // Write to the file. We don't read the contents, but it may help with user discoverability if they change their mind
                    fs.writeFileSync(firstRunPath, "installHomebrew = " + (shouldInstall ? "yes" : "no") + "\n");
                    deferred.resolve({});
                });
            });
        }
        else {
            deferred.resolve({});
        }
        return deferred.promise;
    }
    printUsage(language) {
        console.info(resources.getStringForLanguage(language, "UsageInformation"));
    }
    resetServerCert(conf) {
        return certs.resetServerCert(conf);
    }
    generateClientCert(conf) {
        return certs.generateClientCert(conf);
    }
    initializeServerCerts(conf) {
        return certs.initializeServerCerts(conf);
    }
    getServerCerts(conf) {
        return certs.getServerCerts(conf);
    }
    removeAllCertsSync(conf) {
        certs.removeAllCertsSync(conf);
    }
    downloadClientCerts(req, res) {
        Q.fcall(certs.downloadClientCerts, req.params.pin).catch(function (error) {
            if (error.code) {
                res.send(error.code, resources.getStringForLanguage(req, error.id));
            }
            else {
                res.send(404, error);
            }
            return "";
        }).then(function (pfxFile) {
            res.sendfile(pfxFile);
        }).then(function () { certs.invalidatePIN(req.params.pin); }).done();
    }
}
var darwinSpecifics = new DarwinSpecifics();
module.exports = darwinSpecifics;
